@@ -1,4 +1,7 @@
 import os
+from importlib import util
+from typing import Any
+
 from ..file_io.data_reader import DataReader
 from ..tools.experiment_iterator import ExperimentIterator
 
@@ -40,3 +43,16 @@ class ExperimentConfiguration:
 
     def __contains__(self, key):
         return key in self._sub_folders
+
+
+def get_config_from_external_module(
+        module_path: str,
+        generating_function: str,
+        **function_keyword_arguments: Any
+) -> ExperimentConfiguration:
+    spec = util.spec_from_file_location('config_module', module_path)
+    config_module = util.module_from_spec(spec)
+    spec.loader.exec_module(config_module)
+    func = getattr(config_module, generating_function)
+    config = func(**function_keyword_arguments)
+    return config
